usbengines/usbotgwatcher/inc/cusbstatehostainitiate.h
branchRCL_3
changeset 7 ff9df6630274
parent 6 a15c582fbf97
--- a/usbengines/usbotgwatcher/inc/cusbstatehostainitiate.h	Fri Mar 12 15:48:40 2010 +0200
+++ b/usbengines/usbotgwatcher/inc/cusbstatehostainitiate.h	Mon Mar 15 12:44:42 2010 +0200
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
+ * Copyright (c) 2008 Nokia Corporation and/or its subsidiary(-ies).
  * All rights reserved.
  * This component and the accompanying materials are made available
  * under the terms of "Eclipse Public License v1.0"
@@ -102,27 +102,33 @@
     // From Host Event notification observer
     /**
      * Device is attached
      * @param Device event data
      */
-    void DeviceAttachedL(TDeviceEventInformation);
+    void DeviceAttachedL(TDeviceEventInformation aInfo);
+    
+    /**
+     * Device is detached
+     * @param aInfo Device event data
+     */
+    void DeviceDetachedL(TDeviceEventInformation aInfo);
 
     /**
      * Device is detached
      * @param Device event data
      */
-    void DriverLoadSuccessL(TDeviceEventInformation);
+    void DriverLoadSuccessL(TDeviceEventInformation aInfo);
 
     /**
      * Drivers loaded partially
      * @param Device event data
      */
-    void DriverLoadPartialSuccessL(TDeviceEventInformation);
+    void DriverLoadPartialSuccessL(TDeviceEventInformation aInfo);
 
     /**
      * Drivers loading failed
      * @param Device event data
      */
-    void DriverLoadFailureL(TDeviceEventInformation);
+    void DriverLoadFailureL(TDeviceEventInformation aInfo);
 
 private:
     // data
@@ -133,6 +139,10 @@
      */
     CUsbTimer* iAttachmentTimer;
 
+    /*
+     * attachment attribute
+     */
+    TBool iDeviceAttached;
     };
 
 #endif //  C_USBSTATEHOSTINITIATE_H
@@ -102,27 +102,33 @@
     /**
      * Device is attached
-     * @param Device event data
+     * @param aInfo Device event data
      */
@@ -102,27 +102,33 @@
     /**
      * Device is detached
-     * @param Device event data
+     * @param aInfo Device event data
      */
@@ -102,27 +102,33 @@
     /**
      * Drivers loaded partially
-     * @param Device event data
+     * @param aInfo Device event data
      */
@@ -102,27 +102,33 @@
     /**
      * Drivers loading failed
-     * @param Device event data
+     * @param aInfo Device event data
      */